@@ -50,24 +50,26 @@
      TOK_OFF = 266,
      TOK_FLAG = 267,
      TOK_PURPOSE = 268,
-     TOK_DEFAULT = 269,
-     TOK_GROUP = 270,
-     TOK_GROUPDESC = 271,
-     TOK_MULTIPLE = 272,
-     TOK_ARGOPTIONAL = 273,
-     TOK_TYPESTR = 274,
-     TOK_SECTION = 275,
-     TOK_SECTIONDESC = 276,
-     TOK_TEXT = 277,
-     TOK_ARGS = 278,
-     TOK_VALUES = 279,
-     TOK_HIDDEN = 280,
-     TOK_DEPENDON = 281,
-     TOK_STRING = 282,
-     TOK_MLSTRING = 283,
-     TOK_CHAR = 284,
-     TOK_ARGTYPE = 285,
-     TOK_SIZE = 286
+     TOK_DESCRIPTION = 269,
+     TOK_USAGE = 270,
+     TOK_DEFAULT = 271,
+     TOK_GROUP = 272,
+     TOK_GROUPDESC = 273,
+     TOK_MULTIPLE = 274,
+     TOK_ARGOPTIONAL = 275,
+     TOK_TYPESTR = 276,
+     TOK_SECTION = 277,
+     TOK_SECTIONDESC = 278,
+     TOK_TEXT = 279,
+     TOK_ARGS = 280,
+     TOK_VALUES = 281,
+     TOK_HIDDEN = 282,
+     TOK_DEPENDON = 283,
+     TOK_STRING = 284,
+     TOK_MLSTRING = 285,
+     TOK_CHAR = 286,
+     TOK_ARGTYPE = 287,
+     TOK_SIZE = 288
    };
 #endif
 /* Tokens.  */
@@ -82,24 +84,26 @@
 #define TOK_OFF 266
 #define TOK_FLAG 267
 #define TOK_PURPOSE 268
-#define TOK_DEFAULT 269
-#define TOK_GROUP 270
-#define TOK_GROUPDESC 271
-#define TOK_MULTIPLE 272
-#define TOK_ARGOPTIONAL 273
-#define TOK_TYPESTR 274
-#define TOK_SECTION 275
-#define TOK_SECTIONDESC 276
-#define TOK_TEXT 277
-#define TOK_ARGS 278
-#define TOK_VALUES 279
-#define TOK_HIDDEN 280
-#define TOK_DEPENDON 281
-#define TOK_STRING 282
-#define TOK_MLSTRING 283
-#define TOK_CHAR 284
-#define TOK_ARGTYPE 285
-#define TOK_SIZE 286
+#define TOK_DESCRIPTION 269
+#define TOK_USAGE 270
+#define TOK_DEFAULT 271
+#define TOK_GROUP 272
+#define TOK_GROUPDESC 273
+#define TOK_MULTIPLE 274
+#define TOK_ARGOPTIONAL 275
+#define TOK_TYPESTR 276
+#define TOK_SECTION 277
+#define TOK_SECTIONDESC 278
+#define TOK_TEXT 279
+#define TOK_ARGS 280
+#define TOK_VALUES 281
+#define TOK_HIDDEN 282
+#define TOK_DEPENDON 283
+#define TOK_STRING 284
+#define TOK_MLSTRING 285
+#define TOK_CHAR 286
+#define TOK_ARGTYPE 287
+#define TOK_SIZE 288
 
 
 
@@ -117,7 +121,7 @@ typedef union YYSTYPE
     struct multiple_size *multiple_size;
 }
 /* Line 1529 of yacc.c.  */
-#line 121 "parser.h"
+#line 125 "parser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
